#[non_exhaustive]pub enum Request {
Destroy,
GetCornerRadius {
id: New<CosmicCornerRadiusToplevelV1>,
toplevel: XdgToplevel,
},
}Available on crate feature
server only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Destroy
Destroy the global
Informs the server, that the client will no longer use this global. Any previously created corner-radius objects remain valid until destroyed.
This is a destructor, once received this object cannot be used any longer.
GetCornerRadius
Create a new corner-radius object for an existing toplevel
Instantiate an interface extension for the given xdg_toplevel to specify their corner radius.
If the given xdg_toplevel already has a cosmic_corner_radius_toplevel_v1 object associated, the corner_radius_exists protocol error will be raised.
Fields

id: New<CosmicCornerRadiusToplevelV1>the new cosmic_corner_radius_toplevel_v1 object

toplevel: XdgToplevelthe toplevel
Implementations